@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-#   Copyright (c) 2008-2011, David P. D. Moss. All rights reserved.
+#   Copyright (c) 2008-2012, David P. D. Moss. All rights reserved.
 #
 #   Released under the BSD license. See the LICENSE file for details.
 #-----------------------------------------------------------------------------
@@ -12,7 +12,7 @@ blocks depending on the range specified.
 Each octets can be represented with hyphenated range sets according to the
 following rules:
 
-    1. * C{'x-y'} - the hyphenated octet (represents values x through y)
+    1. * ``x-y`` - the hyphenated octet (represents values x through y)
     2. x must be less than or equal to y
     3. x and y must be values between 0 through 255
 
@@ -30,9 +30,9 @@ from netaddr.ip import IPAddress
 #-----------------------------------------------------------------------------
 def valid_nmap_range(iprange):
     """
-    @param iprange: an nmap-style IP address range.
+    :param iprange: an nmap-style IP address range.
 
-    @return: C{True} if IP range is valid, C{False} otherwise.
+    :return: ``True`` if IP range is valid, ``False`` otherwise.
     """
     status = True
     if not hasattr(iprange, 'split'):
@@ -78,9 +78,9 @@ def iter_nmap_range(iprange):
     hyphenated octets. This generator provides iterators yielding IP addresses
     according to this rule set.
 
-    @param iprange: an nmap-style IP address range.
+    :param iprange: an nmap-style IP address range.
 
-    @return: an iterator producing IPAddress objects for each IP in the range.
+    :return: an iterator producing IPAddress objects for each IP in the range.
     """
     if not valid_nmap_range(iprange):
         raise AddrFormatError('invalid nmap range: %s' % iprange)
