@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-#   Copyright (c) 2008-2011, David P. D. Moss. All rights reserved.
+#   Copyright (c) 2008-2012, David P. D. Moss. All rights reserved.
 #
 #   Released under the BSD license. See the LICENSE file for details.
 #-----------------------------------------------------------------------------
@@ -152,3 +152,8 @@ classifiers = [
     'Topic :: Text Processing :: Filters',
     'Topic :: Utilities',
 ]
+
+install_requires = [
+    'IPython',
+    'Sphinx',
+]
